==> foundation-2.6.1.tgz: package/Power/Power.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Power = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.587 22.655l-.043.043a2.171 2.171 0 00-1.484-.59c-.553 0-1.052.212-1.437.551l-.001-.004-.09.08c-.006.006-.013.01-.018.016l-4.123 3.632c-.032.029-.067.055-.098.086l-.008.006.001.001a2.175 2.175 0 00.405 3.364c4.863 4.973 7.869 11.77 7.869 19.257 0 15.196-12.362 27.559-27.56 27.559-15.199 0-27.561-12.362-27.561-27.559 0-7.561 3.062-14.42 8.01-19.406l-.048-.048c.464-.4.765-.986.765-1.647 0-.591-.237-1.126-.619-1.52l.001-.001-.008-.006c-.031-.031-.066-.057-.098-.086l-4.123-3.632c-.006-.006-.013-.01-.018-.016l-.09-.08-.001.004a2.166 2.166 0 00-1.437-.551c-.809 0-1.508.445-1.885 1.1C16.458 29.94 12.5 39.054 12.5 49.097c0 20.71 16.788 37.498 37.5 37.498s37.5-16.788 37.5-37.498c0-10.317-4.169-19.662-10.913-26.442z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M47.203 62.733h5.593a2.184 2.184 0 002.184-2.184V15.594h-.001l.001-.005a2.184 2.184 0 00-2.184-2.184h-5.592a2.185 2.185 0 00-2.18 2.187l-.001.002v44.955c0 1.206.976 2.182 2.18 2.184z"
  }));
});
Power.displayName = 'Power';
export const PowerDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Power/Power.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Power = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.587 22.655l-.043.043a2.171 2.171 0 00-1.484-.59c-.553 0-1.052.212-1.437.551l-.001-.004-.09.08c-.006.006-.013.01-.018.016l-4.123 3.632c-.032.029-.067.055-.098.086l-.008.006.001.001a2.175 2.175 0 00.405 3.364c4.863 4.973 7.869 11.77 7.869 19.257 0 15.196-12.362 27.559-27.56 27.559-15.199 0-27.561-12.362-27.561-27.559 0-7.561 3.062-14.42 8.01-19.406l-.048-.048c.464-.4.765-.986.765-1.647 0-.591-.237-1.126-.619-1.52l.001-.001-.008-.006c-.031-.031-.066-.057-.098-.086l-4.123-3.632c-.006-.006-.013-.01-.018-.016l-.09-.08-.001.004a2.166 2.166 0 00-1.437-.551c-.809 0-1.508.445-1.885 1.1C16.458 29.94 12.5 39.054 12.5 49.097c0 20.71 16.788 37.498 37.5 37.498s37.5-16.788 37.5-37.498c0-10.317-4.169-19.662-10.913-26.442z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M47.203 62.733h5.593a2.184 2.184 0 002.184-2.184V15.594h-.001l.001-.005a2.184 2.184 0 00-2.184-2.184h-5.592a2.185 2.185 0 00-2.18 2.187l-.001.002v44.955c0 1.206.976 2.182 2.18 2.184z"
  }));
});
Power.displayName = 'Power';
export var PowerDimensions = {
  height: 100,
  width: 100
};
